@@ -171,6 +171,11 @@ static EelEnumerationEntry date_format_entries[] = {
 	{ "informal",	   "Informal",		NAUTILUS_DATE_FORMAT_INFORMAL }
 };
 
+static EelEnumerationEntry new_tab_position_entries[] = {
+	{ "after_current_tab",  "After Current Tab",	NAUTILUS_NEW_TAB_POSITION_AFTER_CURRENT_TAB },
+	{ "end",		"End",			NAUTILUS_NEW_TAB_POSITION_END }
+};
+
 /*
  * A callback which can be used to fetch dynamic fallback values.
  * For example, values that are dependent on the environment (such as user name) 
@@ -333,6 +338,16 @@ static const PreferenceDefault preference_defaults[] = {
 	  PREFERENCE_BOOLEAN,
 	  GINT_TO_POINTER (FALSE)
 	},
+	{ NAUTILUS_PREFERENCES_ENABLE_TABS,
+	  PREFERENCE_BOOLEAN,
+	  GINT_TO_POINTER (TRUE)
+	},
+	{ NAUTILUS_PREFERENCES_NEW_TAB_POSITION,
+	  PREFERENCE_STRING,
+	  "after_current_tab",
+	  NULL, NULL,
+	  "new_tab_position"
+	},
 	{ NAUTILUS_PREFERENCES_START_WITH_TOOLBAR,
 	  PREFERENCE_BOOLEAN,
 	  GINT_TO_POINTER (TRUE)
@@ -417,7 +432,12 @@ static const PreferenceDefault preference_defaults[] = {
 	  PREFERENCE_INTEGER,
 	  GINT_TO_POINTER (96)
 	},
-
+	{ NAUTILUS_PREFERENCES_ICON_VIEW_TEXT_ELLIPSIS_LIMIT,
+	  PREFERENCE_STRING_ARRAY,
+	  "3",
+	  NULL,NULL,
+	  NULL,
+	},
 	/* Compact Icon View Default Preferences */
 	{ NAUTILUS_PREFERENCES_COMPACT_VIEW_DEFAULT_ZOOM_LEVEL,
 	  PREFERENCE_STRING,
@@ -506,7 +526,7 @@ static const PreferenceDefault preference_defaults[] = {
 	  PREFERENCE_BOOLEAN,
 	  GINT_TO_POINTER (FALSE)
 	},
-	{ NAUTILUS_PREFERENCES_MEDIA_AUTORUN_X_CONTENT_ASK,
+	{ NAUTILUS_PREFERENCES_MEDIA_AUTORUN_X_CONTENT_START_APP,
 	  PREFERENCE_STRING_ARRAY,
 	  "", NULL, NULL, NULL
 	},
@@ -518,6 +538,10 @@ static const PreferenceDefault preference_defaults[] = {
 	  PREFERENCE_STRING_ARRAY,
 	  "", NULL, NULL, NULL
 	},	
+	{ NAUTILUS_PREFERENCES_DESKTOP_TEXT_ELLIPSIS_LIMIT,
+	  PREFERENCE_INTEGER,
+	  GINT_TO_POINTER (3)
+	},
 	{ NULL }
 };
 
@@ -604,6 +628,9 @@ global_preferences_register_enumerations (void)
 	eel_enumeration_register ("date_format",
 				  date_format_entries,
 				  G_N_ELEMENTS (date_format_entries));
+	eel_enumeration_register ("new_tab_position",
+				  new_tab_position_entries,
+				  G_N_ELEMENTS (new_tab_position_entries));
 
 	/* Set the enumeration ids for preferences that need them */
 	for (i = 0; preference_defaults[i].name != NULL; i++) {
